#
# This file is part of the Ingram Micro CloudBlue Connect EaaS Extension Library.
#
# Copyright (c) 2022 Ingram Micro. All Rights Reserved.
#

"""
Module messages definition file
"""

PARAMETER_NOT_FOUND = ('The required parameter "{param_id}" is not configured. '
                       'Please, set up this parameter to continue with the request.')

CONFIGURATION_ERROR_PARAMETER = 'A configuration error received getting parameter "{id}".'
CONFIGURATION_ERROR_ENVIRONMENT_VARIABLE = 'A configuration error received getting service environment variable "{id}".'
CLIENT_ERROR = 'An error occurred while approving the Connect request'
